# -*- coding: utf-8 -*-


# import #####################################################################

import sys
from collections import defaultdict
from BeautifulSoup import BeautifulSoup


# constants ##################################################################

NAME = "infovis-%s.html"


# globals ####################################################################

publication_titles = {}
author_names = {}
publication_authors = defaultdict(list)
author_ids = {}


def id_text_from_anchor(a):
	url = a["href"]
	_, args = url.split("?")
	_, id_ = args.split("&")[0].split("=")
	assert _ == "id"

	text = a.text.replace("\n", "")
	return id_, text

def process(year=2011):
	html = open(NAME % year).read()
	soup = BeautifulSoup(html)
	table = soup.find("table", "text12")
	for pub_td in table.findAll("td", colspan="1"):
		# publication
		pub_id, title = id_text_from_anchor(pub_td.find("a"))
		
		assert pub_id not in publication_titles
		publication_titles[pub_id] = title
		
		# authors
		author_tr = pub_td.parent.findNextSibling("tr")
		pages_tr = author_tr.findNextSibling("tr")
		
		pages = pages_tr.text.strip()
		if not pages.startswith("Page"):
			continue
		if pages[-1] not in "0123456789": # exclude front and back matter (roman numerals)
			continue
		
		for author_a in author_tr.findAll("a"):
			author_id, _ = id_text_from_anchor(author_a)
			publication_authors[pub_id].append(author_id)


for year in range(2006, 2012):
	process(year)

with open("publications.txt", "w") as f:
	for pub_id in publication_authors:
		for author_id in publication_authors[pub_id]:
			f.write("%s %s\n" % (pub_id, author_id))

with open("titles.txt", "w") as f:
	for pub_id in publication_authors:
		f.write(("%s %s\n" % (pub_id, publication_titles[pub_id])).encode("utf-8"))
